summaryrefslogtreecommitdiffstats
path: root/generic/tclFCmd.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclFCmd.c')
-rw-r--r--generic/tclFCmd.c15
1 files changed, 8 insertions, 7 deletions
diff --git a/generic/tclFCmd.c b/generic/tclFCmd.c
index ffee889..ebbc109 100644
--- a/generic/tclFCmd.c
+++ b/generic/tclFCmd.c
@@ -141,12 +141,12 @@ FileCopyRename(interp, argc, argv, copyFlag)
result = TCL_OK;
/*
* Call stat() so that if target is a symlink that points to a directory
* we will put the sources in that directory instead of overwriting the
* symlink.
*/
- if ((stat(target, &statBuf) != 0) || !S_ISDIR(statBuf.st_mode)) {
+ if ((TclStat(target, &statBuf) != 0) || !S_ISDIR(statBuf.st_mode)) {
if ((argc - i) > 2) {
errno = ENOTDIR;
Tcl_PosixError(interp);
@@ -253,11 +253,12 @@ TclFileMakeDirsCmd(interp, argc, argv)
char *target = Tcl_JoinPath(j + 1, pargv, &targetBuffer);
/*
* Call stat() so that if target is a symlink that points to a
* directory we will create subdirectories in that directory.
*/
- if (stat(target, &statBuf) == 0) {
+ if (TclStat(target, &statBuf) == 0) {
if (!S_ISDIR(statBuf.st_mode)) {
errno = EEXIST;
errfile = target;
@@ -141,12 +141,12 @@ FileCopyRename(interp, argc, argv, copyFlag)
result = TCL_OK;
/*
- * Call stat() so that if target is a symlink that points to a directory
- * we will put the sources in that directory instead of overwriting the
- * symlink.
+ * Call TclStat() so that if target is a symlink that points to a
+ * directory we will put the sources in that directory instead of
+ * overwriting the symlink.
*/
@@ -253,11 +253,12 @@ TclFileMakeDirsCmd(interp, argc, argv)
char *target = Tcl_JoinPath(j + 1, pargv, &targetBuffer);
/*
- * Call stat() so that if target is a symlink that points to a
- * directory we will create subdirectories in that directory.
+ * Call TclStat() so that if target is a symlink that points
+ * to a directory we will create subdirectories in that
+ * directory.
*/